timesignaturetools.MetricalKernel
=================================

.. abjad-lineage:: abjad.tools.timesignaturetools.MetricalKernel.MetricalKernel.MetricalKernel

.. autoclass:: abjad.tools.timesignaturetools.MetricalKernel.MetricalKernel.MetricalKernel
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.timesignaturetools.MetricalKernel.MetricalKernel.MetricalKernel.kernel
   :noindex:

.. autoattribute:: abjad.tools.timesignaturetools.MetricalKernel.MetricalKernel.MetricalKernel.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.timesignaturetools.MetricalKernel.MetricalKernel.MetricalKernel.__call__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalKernel.MetricalKernel.MetricalKernel.__eq__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalKernel.MetricalKernel.MetricalKernel.__ge__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalKernel.MetricalKernel.MetricalKernel.__gt__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalKernel.MetricalKernel.MetricalKernel.__le__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalKernel.MetricalKernel.MetricalKernel.__lt__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalKernel.MetricalKernel.MetricalKernel.__ne__
   :noindex:

.. automethod:: abjad.tools.timesignaturetools.MetricalKernel.MetricalKernel.MetricalKernel.__repr__
   :noindex:
